@@ -18,9 +18,8 @@ __all__ = [
     "newline_at_end_of_file",
     "subscriptor",
     "header",
-    "comments"
+    "comments",
+    "nb_params"
 ]
 
-PREVIEW = [
-   "nb_params"
-]
+PREVIEW = []
