@@ -22,6 +22,8 @@ def check(context: Context, file: CFileParse) -> (int, int, list):
     nb_error = 0
     list_error = []
 
+    if file.filepath.endswith("Makefile"):
+        return (nb_error, 0, list_error)
     for i in range(len(file.sub_parsedline)):
         line = file.sub_parsedline[i]
         if line[0] != TypeLine.COMMENT:
