@@ -16,6 +16,8 @@ def check(context, file: CFileParse) -> (int, int, list):
             "<", ">", ")"
     ]
 
+    if file.filepath.endswith("Makefile"):
+        return (nb_error, 1, list_error)
     for i in range(len(file.sub_parsedline)):
         line = file.sub_parsedline[i]
         if line[0] != TypeLine.COMMENT:
