@@ -10,13 +10,13 @@ def check(context, file: CFileParse) -> (int, int, list):
     list_error = []
     last_is_no = False
 
-    for i in range(len(file.sub_parsedline) - 1):
-        if file.sub_parsedline[i][0] not in [TypeLine.COMMENT]:
-            if last_is_no and file.sub_parsedline[i][1] == '':
+    for i in range(len(file.real_parsedline) - 1):
+        if file.real_parsedline[i][0] not in [TypeLine.COMMENT]:
+            if last_is_no and file.real_parsedline[i][1] == '':
                 nb_error += 1
                 list_error.append((i + 1, f"no 2 newline between functions"))
                 last_is_no = False
-            elif last_is_no == False and file.sub_parsedline[i][1] == '':
+            elif last_is_no == False and file.real_parsedline[i][1] == '':
                 last_is_no = True
             else:
                 last_is_no = False
