@@ -57,12 +57,15 @@ def call_plugged(context: Context, files: list, list_checkers: list, pwd: str) -
     stats = []
     nb_files_total = len(files)
     checkers = get_modules(list_checkers)
+    nb_total_line = 0
+
     for i, file in enumerate(files):
         if context.only_error == False:
             color.print_color("cyan", f"file [{file}] n°{i + 1}/{nb_files_total}...")
-        parse: file_parser.CFileParse = file_parser.parse(file, pwd)
+        parse, nb_line = file_parser.parse(file, pwd)
+        nb_total_line += nb_line
         curr_stat, last_nb_error = itter_mod(context, parse, checkers)
         if last_nb_error != 0:
             nb_error += last_nb_error
             stats.extend(curr_stat)
-    return (stats, nb_error)
+    return (stats, nb_error, nb_total_line)
